/*
  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-only
*/

#ifndef FILTERIMPORTERAKONADITEST_H
#define FILTERIMPORTERAKONADITEST_H

#include <QObject>

class FilterImporterAkonadiTest : public QObject
{
    Q_OBJECT
public:
    explicit FilterImporterAkonadiTest(QObject *parent = nullptr);
    ~FilterImporterAkonadiTest() = default;
};

#endif // FILTERIMPORTERAKONADITEST_H
