/*
  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "filterimportertestutil.h"

FilterImporterTestUtil::FilterImporterTestUtil(const QString &filename)
    : mFileName(filename)
{
}

QString FilterImporterTestUtil::extractData()
{
    // TODO
    return {};
}
