/*
  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-only
*/

#include "filterimporterakonaditest.h"

#include <QTest>

FilterImporterAkonadiTest::FilterImporterAkonadiTest(QObject *parent)
    : QObject(parent)
{
}

QTEST_MAIN(FilterImporterAkonadiTest)
