/*
  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-only
*/

#ifndef FILTERICEDOVETEST_H
#define FILTERICEDOVETEST_H

#include <QObject>

class FilterIcedoveTest : public QObject
{
    Q_OBJECT
public:
    explicit FilterIcedoveTest(QObject *parent = nullptr);
    ~FilterIcedoveTest();
private Q_SLOTS:
    void shouldHaveDefaultSettingsPath();
    void shouldImportData();
    void canNotImportDataEmptyPath();
    void canNotImportDataUnknowPath();
    void canNotImportDataWhenHomeDirSelected();
};

#endif // FILTERICEDOVETEST_H
